//
//  SafariWebExtensionHandler.swift
//  CashbackExtension
//
//  Created by Shems Boukhatem on 15/12/2021.
//

import SafariServices
import os.log
import AdSupport
import AppTrackingTransparency

class SafariWebExtensionHandler: KindredSWEHandler {

    override init() {
        super.init()
        
        let locale = Locale.current

        let currency = locale.currencyCode ?? "USD"
        let country = locale.regionCode ?? "US"

        if (!KindredSettings.shared.isValueSet(key: DataKey.KKUserCurrencyKey)) {
            KindredSettings.shared.saveSetting(obj: currency, key: DataKey.KKUserCurrencyKey)
        }
        
        if (!KindredSettings.shared.isValueSet(key: DataKey.KKUserCountryKey)) {
            KindredSettings.shared.saveSetting(obj: country, key: DataKey.KKUserCountryKey)
        }

        self.setRandomUserId()
        self.setShowEarthmark(enabled: true)
        
        // Opt in for Kindred Analytics
        // self.setUseAnalytics(enabled: true)
        
        // Opt out from Device ID capture
        // self.optOutFromDeviceIDCapture()
        
        KindredSettings.shared.saveSetting(obj: "kindredsafariextensionsampleapp", key: DataKey.KKAppSchemeKey)
        self.setDeviceIDFV()
        self.setDeviceIDFA()
    }

    func setRandomUserId() {
        if KindredSettings.shared.getSetting(key: DataKey.KKUserIdKey).isEmpty {
            let userId = UUID().uuidString
            KindredSettings.shared.saveSetting(obj: userId, key: DataKey.KKUserIdKey)
        }
    }
    
    func setShowCashbackLabel(enabled: Bool) {
        KindredSettings.shared.saveSetting(obj: enabled, key: DataKey.KKShowCashbackLabelKey)
    }
    
    func setShowEarthmark(enabled: Bool) {
        KindredSettings.shared.saveSetting(obj: enabled, key: DataKey.KKShowEarthmarkKey)
    }
    
    func setUseAnalytics(enabled: Bool) {
        KindredSettings.shared.saveSetting(obj: enabled, key: DataKey.KKUseAnalytics)
    }
    
    func setPartnerId(partnerId: String) {
        KindredSettings.shared.saveSetting(obj: partnerId, key: DataKey.KKPartnerId)
    }
    
    func optOutFromDeviceIDCapture() {
        KindredSettings.shared.saveSetting(obj: true, key: DataKey.KKOptOutFromDeviceIDCapture)
    }
    
    func setDeviceIDFV() {
        if let idfv = UIDevice.current.identifierForVendor?.uuidString {
            KindredSettings.shared.saveSetting(obj: idfv, key: DataKey.KKDeviceIDFV)
        }
    }
    
    func setDeviceIDFA() {
        if (!KindredSettings.shared.isValueSet(key: DataKey.KKOptOutFromDeviceIDCapture)) {
            let status = ATTrackingManager.trackingAuthorizationStatus
            if status == .authorized {
                let idfa = ASIdentifierManager.shared().advertisingIdentifier.uuidString
                KindredSettings.shared.saveSetting(obj: idfa, key: DataKey.KKDeviceIDFA)
            }
        }
    }
}
